@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gst2perl.h,v 1.2 2005/03/25 18:25:45 kaffeetisch Exp $
+ * $Id: gst2perl.h,v 1.5 2005/06/01 18:01:15 kaffeetisch Exp $
  */
 
 #ifndef _GST2PERL_H_
@@ -58,4 +58,17 @@ GstClockID SvGstClockID (SV *sv);
 void gst2perl_event_initialize (void);
 void gst2perl_value_initialize (void);
 
+/* Even yet one more stupid hack. */
+#undef SvGstSeekType
+GstSeekType SvGstSeekType (SV *type);
+
+/* Hacks to get large integers working. */
+typedef gint64 GstInt64;
+SV * newSVGstInt64 (gint64 value);
+gint64 SvGstInt64 (SV *sv);
+
+typedef guint64 GstUInt64;
+SV * newSVGstUInt64 (guint64 value);
+guint64 SvGstUInt64 (SV *sv);
+
 #endif /* _GST2PERL_H_ */
